# Reviews on microlensing

Here is a selection of reviews that can be useful to learn about microlensing and its applications.

["Microlensing Searches for Exoplanets" by Y. Tsapras (2018)](https://ui.adsabs.harvard.edu/abs/2018Geosc...8..365T/abstract)

["Microlensing Surveys for Exoplanets" by B.S. Gaudi (2012)](https://ui.adsabs.harvard.edu/abs/2012ARA%26A..50..411G/abstract)

["Astrophysical applications of gravitational microlensing" by S. Mao (2012)](https://ui.adsabs.harvard.edu/abs/2012RAA....12..947M/abstract)

["Planetary Microlensing: from Prediction to Discovery" by N. Rattenbury (2006)](https://ui.adsabs.harvard.edu/abs/2006MPLA...21..919R/abstract)
